@@ -34,6 +34,22 @@ def decodeCustomTx(hex):
         res = decodeCreatePoolPair(hex[2:])
         if res != None:
             res['name'] = 'createpoolpair'
+    elif functionMarker == 'B':
+        res = decodeAccountToAccount(hex[2:])
+        if res != None:
+            res['name'] = 'accounttoaccount'
+    elif functionMarker == 'X':
+        res = decodeTakeLoan(hex[2:])
+        if res != None:
+            res['name'] = 'takeloan'
+    elif functionMarker == 'H':
+        res = decodePaybackLoan(hex[2:])
+        if res != None:
+            res['name'] = 'paybackloan'
+    elif functionMarker == 'k':
+        res = decodePaybackLoanV2(hex[2:])
+        if res != None:
+            res['name'] = 'paybackloanv2'
     else:
         c = CustomTxType()
         for key, value in asdict(c).items():
@@ -136,7 +152,51 @@ def decodeCreatePoolPair(hex):
         {'bytesCount':1, 'key': 'status', 'type': int,'endian':None}
     ]
     return searchHex(variables,hex)
-
+def decodeAccountToAccount(hex):
+    variables = [
+        {'key': 'from', 'type': 'address','endian':None},
+        {'key':'addresses', 'type': [
+            {'key': 'to', 'type': 'address','endian':None},
+            {'key': 'amounts', 'type': [
+                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+                {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+                ]}
+        ]}
+    ]
+    return searchHex(variables,hex)
+def decodeTakeLoan(hex):
+    variables = [
+        {'bytesCount': 32,'key': 'vault', 'type': 'hex','endian':'little'},
+        {'key': 'to', 'type': 'address','endian':None},
+        {'key': 'amounts', 'type': [
+            {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+            {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+        ]}
+    ]
+    return searchHex(variables,hex)
+def decodePaybackLoan(hex):
+    variables = [
+        {'bytesCount': 32,'key': 'vault', 'type': 'hex','endian':'little'},
+        {'key': 'from', 'type': 'address','endian':None},
+        {'key': 'amounts', 'type': [
+            {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+            {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+        ]}
+    ]
+    return searchHex(variables,hex)
+def decodePaybackLoanV2(hex):
+    variables = [
+        {'bytesCount': 32,'key': 'vault', 'type': 'hex','endian':'little'},
+        {'key': 'from', 'type': 'address','endian':None},
+        {'key': 'tokens', 'type': [
+            {'bytesCount': 1,'key': 'tokenId', 'type': int,'endian':None},
+            {'key': 'amounts', 'type': [
+                {'bytesCount': 4,'key': 'tokenId', 'type': int,'endian':'little'},
+                {'bytesCount': 8, 'key': 'amount', 'type': int,'endian':'little'}
+            ]}
+        ]}
+    ]
+    return searchHex(variables,hex)
 def recursiveSearchHex(variable,hex):
     if type(variable['type']) == list:
         cnt = int(hex[:2],16)
@@ -170,6 +230,8 @@ def searchHex(variables:list,hex:str):
 def getValue(variable,hex):
     # Select subString from hex depending on length info in hex String or length info from variable input
     if variable['type'] == 'address':
+        if 'key' in variable and variable['key'] == 'to' and hex[:2] == '00':
+            return variable['key'],None,hex[2:]
         # START - Remove leading zeros
         while True:
             if len(hex) >= 2 and hex[:2] == '00':
@@ -221,6 +283,8 @@ def getValue(variable,hex):
             valueOfInterest = utils.hexToString(hexOfInterest)
     elif variable['type'] == 'address':
         valueOfInterest = utils.decodeHexToAddress(hexOfInterest,addressType,addressVersion)
+    elif variable['type'] == 'hex':
+        valueOfInterest = hexOfInterest
     else:
         valueOfInterest = None
     
